@@ -25,11 +25,9 @@ fn main() {
         "cargo:rerun-if-changed=build.rs\n\
          cargo:rustc-env=TRYRUN_RUSTC={}\n\
          cargo:rustc-env=TRYRUN_RUSTDOC={}\n\
-         cargo:rustc-env=TRYRUN_TARGET={}\n\
          cargo:rustc-env=TRYRUN_OPT_LEVEL={}",
         rustc,
         env::var("RUSTDOC").unwrap(),
-        env::var("TARGET").unwrap(),
         env::var("OPT_LEVEL").unwrap()
     )
     .unwrap();
