@@ -23,15 +23,13 @@
 //!
 //! ### Test that `cargo build -q` runs successfully and has empty output without normalization
 //! ```
-//! use tryrun::prelude::*;
-//!
+//! # use tryrun::prelude::*;
 //! Command::cargo("build").arg("-q").run_pass(OutputStr::empty(), normalize::noop());
 //! ```
 //!
 //! ### Test that `rustc -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
-//! use tryrun::prelude::*;
-//!
+//! # use tryrun::prelude::*;
 //! Command::rustc().arg("-V").run_pass(
 //!    OutputStr::stdout_only("tests/ui/rustc_version.stdout"),
 //!    normalize::stdout(|output| {
@@ -44,8 +42,7 @@
 //!
 //! ### Test that `rustdoc -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
-//! use tryrun::prelude::*;
-//!
+//! # use tryrun::prelude::*;
 //! Command::rustdoc().arg("-V").run_pass(
 //!    OutputStr::stdout_only("tests/ui/rustdoc_version.stdout"),
 //!    normalize::stdout(|output| {
@@ -58,9 +55,8 @@
 //!
 //! ### Test that `clippy-driver -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
-//! use tryrun::prelude::*;
-//!
-//! Command::new("clippy-driver").rustc_like().arg("-V").run_pass(
+//! # use tryrun::prelude::*;
+//! Command::clippy().arg("-V").run_pass(
 //!     OutputStr::stdout_only("tests/ui/clippy_version.stdout"),
 //!     normalize::stdout(|output| {
 //!         output.truncate("clippy".len());
@@ -72,15 +68,13 @@
 //!
 //! ### Test that `false` runs unsucessfully and has empty output without normalization
 //! ```
-//! use tryrun::prelude::*;
-//!
+//! # use tryrun::prelude::*;
 //! Command::new("false").run_fail(OutputStr::empty(), normalize::noop());
 //! ```
 //!
 //! ### Test that `false garbage` also runs unsucessfully and has empty output without normalization
 //! ```
-//! use tryrun::prelude::*;
-//!
+//! # use tryrun::prelude::*;
 //! Command::new("false").arg("garbage").run_fail(OutputStr::empty(), normalize::noop());
 //! ```
 //!
@@ -220,9 +214,9 @@ impl<N: Normalizer + ?Sized> Normalizer for &mut N {
 /// use tryrun::normalize;
 /// ```
 pub mod normalize {
-    use crate::normalizer::{self, Noop, StdErr, StdOut};
+    use super::normalizer::{self, Noop, StdErr, StdOut};
 
-    /// Returns an instance of [`crate::Normalizer`] that does nothing.
+    /// Returns an instance of [`super::Normalizer`] that does nothing.
     ///
     /// ## Example
     /// ```
@@ -239,7 +233,7 @@ pub mod normalize {
         Noop
     }
 
-    /// Returns an instance of [`crate::Normalizer`] that normalizes both stdout and stderr
+    /// Returns an instance of [`super::Normalizer`] that normalizes both stdout and stderr
     /// using the given closure (or function).
     ///
     /// ## Example
@@ -343,8 +337,8 @@ pub mod normalize {
 
 /// Path to files that store expected [`Command`] stdout and stderr.
 ///
-/// A [`None`] value means expecting stdout or stderr to be empty. Note that providing an
-/// empty file does not work and will resulting an "output is empty" assertion failure.
+/// [`None`] means expecting stdout or stderr to be empty. Note that providing an empty file does
+/// not work and will resulting an "output is empty" assertion failure.
 #[derive(Default, Debug, Clone, Copy)]
 pub struct Output<StdOut, StdErr> {
     /// Path to the stdout file.
@@ -425,7 +419,7 @@ pub type OutputStr = Output<&'static str, &'static str>;
 /// Creates an [`struct@Output`] that expects stdout to match `$base_path.stdout`
 /// and stderr to match `$base_path.stderr`.
 ///
-/// # Example
+/// ## Example
 /// ```
 /// # use tryrun::prelude::*;
 /// const STDOUT_STDERR: OutputStr = tryrun::output!(concat!(env!("OUT_DIR"), "/foo"));
@@ -450,17 +444,16 @@ macro_rules! Output {
 
 /// An extension trait for [`Command`].
 pub trait CommandExt: Sealed {
-    /// Creates a [`Command`] that runs `cargo $subcommand`, with appropriate `--target`
-    /// and `--release` flags.
+    /// Creates a [`Command`] that runs `cargo $subcommand`, with `--release` flag if `tryrun` is
+    /// built in release mode.
     #[must_use]
     fn cargo(subcommand: impl AsRef<OsStr>) -> Self;
 
-    /// Add `--target` and `-Copt-level` flags that are appropriate to `rustc` (or `rustdoc`
-    /// or `clippy-driver` or `miri` or something else that accepts these flags) to
-    /// [`self`](Command).
+    /// Adds some appropriate flags to a `rustc`-like command (such as `rustc` itself, `rustdoc`,
+    /// `clippy-driver` or `miri`).
     fn rustc_like(&mut self) -> &mut Self;
 
-    /// Create a new [`Command`] that runs `rustc` with flags provided by [`Self::rustc_like`].
+    /// Creates a new [`Command`] that runs `rustc` with flags provided by [`Self::rustc_like`].
     #[must_use]
     #[inline(always)]
     fn rustc() -> Self
@@ -472,7 +465,20 @@ pub trait CommandExt: Sealed {
         rustc
     }
 
-    /// Create a new [`Command`] that runs `rustdoc` with flags provided by [`Self::rustc_like`].
+    /// Creates a new [`Command`] that runs `clippy-driver` with flags provided by
+    /// [`Self::rustc_like`].
+    #[must_use]
+    #[inline(always)]
+    fn clippy() -> Self
+    where
+        Self: Sized,
+    {
+        let mut clippy = Self::new("clippy-driver");
+        clippy.rustc_like();
+        clippy
+    }
+
+    /// Creates a new [`Command`] that runs `rustdoc` with flags provided by [`Self::rustc_like`].
     #[must_use]
     #[inline(always)]
     fn rustdoc() -> Self
@@ -663,19 +669,15 @@ impl CommandExt for Command {
     fn cargo(subcommand: impl AsRef<OsStr>) -> Self {
         let mut cargo = Self::new(env!("CARGO"));
         cargo.arg(subcommand).args(&[
-            concat!("--target=", env!("TRYRUN_TARGET")),
             #[cfg(release)]
             "--release",
-        ]);
+        ] as &[&str]);
         cargo
     }
 
     #[inline(always)]
     fn rustc_like(&mut self) -> &mut Self {
-        self.args(&[
-            concat!("--target=", env!("TRYRUN_TARGET")),
-            concat!("-Copt-level=", env!("TRYRUN_OPT_LEVEL")),
-        ])
+        self.args(&[concat!("-Copt-level=", env!("TRYRUN_OPT_LEVEL"))])
     }
 
     #[track_caller]
@@ -745,6 +747,7 @@ mod tests {
     use super::{normalize, CommandExt, Normalizer, Output, OutputStr};
     use std::{
         env::consts,
+        fmt::Debug,
         path::{Path, PathBuf},
         process::Command,
         str,
@@ -775,7 +778,10 @@ mod tests {
         cargo.args(&["-q", "--release"]);
         if cfg!(release) {
             cargo.run_fail(
-                OutputStr::stderr_only("tests/ui/cargo_release.stderr"),
+                Output {
+                    stdout: None::<PathBuf>,
+                    stderr: Path::new("tests/ui/cargo_release.stderr").into(),
+                },
                 strip_exe(),
             );
         } else {
@@ -783,59 +789,68 @@ mod tests {
         }
     }
 
-    #[test]
-    fn cargo_target() {
-        Command::cargo("locate-project").run_fail(
-            OutputStr::stderr_only("tests/ui/cargo_target.stderr"),
-            strip_exe(),
+    #[track_caller]
+    fn assert_rustc_like_args(cmd: impl Debug, program: impl Debug) {
+        assert_eq!(
+            format!("{:?}", cmd),
+            format!(
+                concat!(r#"{:?} "-Copt-level="#, env!("TRYRUN_OPT_LEVEL"), '"'),
+                program
+            )
         );
     }
 
-    fn trim_final_newline() -> impl Normalizer {
-        normalize::stderr(|output| {
-            output.pop().unwrap();
-            output
-        })
+    #[track_caller]
+    fn assert_debug_eq(left: impl Debug, right: impl Debug) {
+        assert_eq!(format!("{:?}", left), format!("{:?}", right));
     }
 
     #[test]
-    fn rustc_target() {
-        Command::rustc().arg("--target=").run_fail(
-            OutputStr::stderr_only("tests/ui/target.stderr"),
-            trim_final_newline(),
+    fn rustc_args() {
+        assert_debug_eq(
+            Command::rustc(),
+            Command::new(env!("TRYRUN_RUSTC")).rustc_like(),
         );
-    }
-
-    fn rustdoc_command() -> Command {
-        let mut rustdoc = Command::rustdoc();
-        rustdoc.arg("--target=");
-        rustdoc
+        assert_rustc_like_args(Command::rustc(), env!("TRYRUN_RUSTC"));
     }
 
     #[test]
-    fn rustdoc_target() {
-        rustdoc_command().run_fail(
-            OutputStr::stderr_only("tests/ui/target.stderr"),
-            trim_final_newline(),
+    fn clippy_args() {
+        assert_debug_eq(
+            Command::clippy(),
+            Command::new("clippy-driver").rustc_like(),
+        );
+        assert_rustc_like_args(Command::clippy(), "clippy-driver");
+    }
+
+    #[test]
+    fn rustdoc_args() {
+        assert_debug_eq(
+            Command::rustdoc(),
+            Command::new(env!("TRYRUN_RUSTDOC")).rustc_like(),
+        );
+        assert_rustc_like_args(Command::rustdoc(), env!("TRYRUN_RUSTDOC"));
+    }
+
+    #[test]
+    fn rustc_like_args() {
+        assert_eq!(
+            format!(
+                "{:?}",
+                Command::new("hello").arg("world").rustc_like().arg("!")
+            ),
+            concat!(
+                r#""hello" "world" "-Copt-level="#,
+                env!("TRYRUN_OPT_LEVEL"),
+                r#"" "!""#
+            )
         );
     }
 
     #[test]
     fn rustdoc_fake_empty() {
-        rustdoc_command().run_fail(OutputStr::empty(), normalize::stderr(|_| &[]));
-    }
-
-    #[test]
-    fn clippy_target() {
-        Command::new("clippy-driver")
-            .rustc_like()
-            .arg("--target=")
-            .run_fail(
-                Output {
-                    stdout: None::<PathBuf>,
-                    stderr: Path::new("tests/ui/target.stderr").into(),
-                },
-                trim_final_newline(),
-            );
+        Command::rustdoc()
+            .arg("--invalid")
+            .run_fail(OutputStr::empty(), normalize::stderr(|_| &[]));
     }
 }
